@@ -5,9 +5,10 @@
 """
 from .woqlClient import *
 from .woql import WOQLQuery
+from .woqlDataframe import *
 from .__version__ import __version__
 
-__all__ = ['woqlClient', 'woql']
+__all__ = ['woqlClient', 'woql', 'woqlDataframe']
 
 name = "woqlclient"
 #__version__ = "0.0.4"
